import requests
from bs4 import BeautifulSoup

# href="((?:http|https):\/\/mrcong.com\/(?!tag\/)[^"]+)


def extract_post_links(url_str: str):
    current_page = 0
    links = []

    while True:
        current_page += 1
        page = requests.get(url_str + f"/page/{current_page}")

        if page.status_code == 404:
            break

        if page.status_code != 200:
            print("err")

        bs = BeautifulSoup(page.text, "lxml")
        links += bs.select('.post-box-title a[href*="mrcong.com"]')

    return links


def extract_download_links(url_str: str):
    page = requests.get(url_str)
    bs = BeautifulSoup(page.text, "lxml")
    links = bs.select('a[href*="mediafire.com"]')

    return links



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['myodan_tools', 'myodan_tools.downloader', 'myodan_tools.extractor']

package_data = \
{'': ['*']}

install_requires = \
['Flask>=2.2.0,<3.0.0',
 'beautifulsoup4>=4.12.2,<5.0.0',
 'bs4>=0.0.1,<0.0.2',
 'lxml>=4.9.2,<5.0.0',
 'numpy>=1.22.2,<2.0.0',
 'rarfile>=4.0,<5.0',
 'replit>=3.2.4,<4.0.0',
 'requests>=2.28.2,<3.0.0',
 'six>=1.16.0,<2.0.0',
 'typer[all]>=0.7.0,<0.8.0',
 'urllib3>=1.26.12,<2.0.0']

entry_points = \
{'console_scripts': ['myodan-tools = myodan-tools.main:app']}

setup_kwargs = {
    'name': 'myodan-tools',
    'version': '0.0.3',
    'description': '',
    'long_description': '# myodan-tools',
    'author': 'Jongho Hong',
    'author_email': 'myodan@pm.me',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10.0,<3.11',
}


setup(**setup_kwargs)



import os
import os.path as osp
import re
import shutil
import sys
import tempfile
import requests
import six

CHUNK_SIZE = 512 * 1024  # 512KB

USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/110.0.5481.178 Safari/537.36"


def extract_download_link(contents):
    for line in contents.splitlines():
        m = re.search(r'href="((?:http|https)://download[^"]+)', line)
        if m:
            return m.groups()[0]


def download(url, output):
    url_origin = url
    sess = requests.session()
    sess.headers = {"User-Agent": USER_AGENT}

    while True:
        res = sess.get(url, stream=True)
        if "Content-Disposition" in res.headers:
            break

        url = extract_download_link(res.text)

        if url is None:
            print("Permission denied: %s" % url_origin, file=sys.stderr)
            print(
                "Maybe you need to change permission over "
                "'Anyone with the link'?",
                file=sys.stderr,
            )

            return

    if output is None:
        origin_filename = re.search(
            'filename="(.*)"',
            res.headers["Content-Disposition"],
        )
        output = origin_filename.groups()[0]
        output = output.encode("iso8859").decode("utf-8")

    output_is_path = isinstance(output, six.string_types)

    print("Downloading...", file=sys.stderr)
    print("From:", url_origin, file=sys.stderr)
    print(
        "To:",
        osp.abspath(output) if output_is_path else output,
        file=sys.stderr,
    )

    if output_is_path:
        temp_file = tempfile.mktemp(
            suffix=tempfile.template,
            prefix=osp.basename(output),
            dir=osp.dirname(output),
        )
        temp_file_buffer = open(temp_file, "wb")

    else:
        temp_file = None
        temp_file_buffer = output

    try:
        total = res.headers.get("Content-Length")

        if total is not None:
            total = int(total)

        for chunk in res.iter_content(chunk_size=CHUNK_SIZE):
            temp_file_buffer.write(chunk)

        if temp_file:
            temp_file_buffer.close()
            shutil.move(temp_file, output)

    except IOError as error:
        print(error, file=sys.stderr)
        return

    finally:
        try:
            if temp_file:
                os.remove(temp_file)

        except OSError:
            pass

    return output



from urllib.parse import urlparse
import typer

from .downloader import mediafire
from .extractor import mrcong

app = typer.Typer()


@app.callback()
def callback(url_str: str):
    url = urlparse(url_str)

    download_links = []

    if "mrcong.com" in url.netloc:
        if "/tag" in url.path:
            post_links = mrcong.extract_post_links(url_str)

            for post_link in post_links:
                download_links += mrcong.extract_download_links(
                    post_link["href"])

        else:
            download_links += mrcong.extract_download_links(url_str)

        for download_link in download_links:
            mediafire.download(download_link["href"], None, quiet=False)


if __name__ == "__main__":
    app()
